@@ -79,6 +79,7 @@ def geom_factory(g, parent=None):
         ob._ndim = 3
     else:
         ob._ndim = 2
+    ob._is_empty = False
     return ob
 
 
@@ -231,6 +232,7 @@ class BaseGeometry(object):
     def __setstate__(self, state):
         self.empty()
         self.__geom__ = deserialize_wkb(state)
+        self._is_empty = False
         if lgeos.methods['has_z'](self.__geom__):
             self._ndim = 3
         else:
@@ -263,7 +265,7 @@ class BaseGeometry(object):
 
     def __eq__(self, other):
         return (
-            isinstance(other, self.__class__) and
+            type(other) == type(self) and
             tuple(self.coords) == tuple(other.coords)
         )
 
@@ -765,7 +767,7 @@ class BaseMultipartGeometry(BaseGeometry):
 
     def __eq__(self, other):
         return (
-            isinstance(other, self.__class__) and
+            type(other) == type(self) and
             len(self) == len(other) and
             all(x == y for x, y in zip(self, other))
         )
